'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.HttpError = void 0;
const goodies_1 = require("@supercharge/goodies");
class HttpError extends Error {
    /**
     * Create a new HTTP error instance.
     *
     * @param {String} message
     */
    constructor(message) {
        super(message);
        Error.captureStackTrace(this, this.constructor);
        this.statusCode = 500;
    }
    /**
     * Returns a new HTTP error instance wrapping the given `error`.
     *
     * @param {*} error
     *
     * @returns {HttpError}
     */
    static wrap(error) {
        return new HttpError(error.message).withStatus(this.retrieveStatusFrom(error));
    }
    /**
     * Retrieves an available status code from the error instance.
     * Falls back to HTTP status 500 if no status code is found.
     *
     * @param error
     *
     * @returns {Number}
     */
    static retrieveStatusFrom(error) {
        return error.status || error.statusCode || 500;
    }
    /**
     * Assign the given HTTP `status` code to this error.
     *
     * @param status
     *
     * @returns {HttpError}
     */
    withStatus(status) {
        return goodies_1.tap(this, () => {
            this.statusCode = status;
        });
    }
}
exports.HttpError = HttpError;
