import { Application, BootstrapperCtor, HttpKernel as HttpKernelContract, MiddlewareCtor } from '@supercharge/contracts';
export declare class HttpKernel implements HttpKernelContract {
    /**
     * Stores the HTTP kernel’s meta data.
     */
    private readonly meta;
    /**
     * The HTTP server instance.
     */
    private readonly server;
    /**
     * Create a new HTTP kernel instance.
     *
     * @param {Application} app
     */
    constructor(app: Application);
    /**
     * Creates a new HTTP kernel instance for the given `app`.
     *
     * @param {Application} app
     */
    static for(app: Application): HttpKernel;
    /**
     * Returns the application’s global middleware stack. Every middleware
     * listed here runs on every request to the application.
     *
     * @returns {MiddlewareCtor[]}
     */
    middleware(): MiddlewareCtor[];
    /**
     * Returns the application’s global middleware stack. Every middleware
     * listed here runs on every request to the application.
     *
     * @returns {MiddlewareCtor[]}
     */
    routeMiddleware(): {
        [key: string]: MiddlewareCtor;
    };
    /**
     * Returns the path to the HTTP controllers.
     *
     * @returns {String}
     */
    protected controllersLocation(): string;
    /**
     * Returns the app instance.
     */
    app(): Application;
    /**
     * Start the HTTP instance listening for incoming requests.
     *
     * @returns {Promise}
     */
    startServer(): Promise<void>;
    /**
     * Bootstrap the application by loading environment variables, load the
     * configuration, register service providers into the IoC container
     * and ultimately boot the registered providers.
     */
    bootstrap(): Promise<void>;
    /**
     * Returns the list of application bootstrappers.
     */
    protected bootstrappers(): BootstrapperCtor[];
    /**
     * Returns an array of file paths to all controllers.
     *
     * @returns {String[]}
     */
    controllerPaths(): Promise<string[]>;
    /**
     * Start the HTTP server.
     */
    private listen;
}
